/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.perf.servlet.provider;

import java.util.Enumeration;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.appspy.client.common.CollectorFactory;
import org.appspy.client.common.CollectorInfo;
import org.appspy.perf.data.ServletTimerData;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class InputHeaderSizeDataProvider extends AbstractDataProvider {

	/* (non-Javadoc)
	 * @see org.appspy.perf.servlet.provider.DataProvider#afterRequest(org.appspy.perf.shared.data.ServletTimerData, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, javax.servlet.ServletContext)
	 */
	public void afterRequest(ServletTimerData servletTimerData, HttpServletRequest req, HttpServletResponse res,
			ServletContext servletContext, Throwable throwable) {

	}

	/* (non-Javadoc)
	 * @see org.appspy.perf.servlet.provider.DataProvider#beforeRequest(org.appspy.perf.shared.data.ServletTimerData, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, javax.servlet.ServletContext)
	 */
	@SuppressWarnings("unchecked")
	public void beforeRequest(ServletTimerData servletTimerData, HttpServletRequest req, HttpServletResponse res,
			ServletContext servletContext) {

		try
		{
			int inputHeaderSize = 0;
			for (Enumeration<String> en = req.getHeaderNames(); en.hasMoreElements(); )
			{
				String headerName = (String) en.nextElement();
				String value = req.getHeader(headerName);
				inputHeaderSize = inputHeaderSize + headerName.length() + 1 + value.length();
			}
			servletTimerData.setInputHeaderSize(inputHeaderSize);
		}
		catch (Throwable t)
		{
			CollectorFactory.getCollectorInfo().setStatus(CollectorInfo.STATUS_ERROR, t);
		}
	}

}
